diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/BatchRetryTemplate.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/BatchRetryTemplate.java
index 103374a8c..f926b8c66 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/BatchRetryTemplate.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/BatchRetryTemplate.java
@@ -21,6 +21,7 @@ import java.util.Collection;
import java.util.Iterator;
import java.util.List;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.retry.ExhaustedRetryException;
import org.springframework.batch.retry.RecoveryCallback;
import org.springframework.batch.retry.RetryCallback;
@@ -35,7 +36,6 @@ import org.springframework.batch.retry.policy.RetryContextCache;
import org.springframework.batch.retry.support.DefaultRetryState;
import org.springframework.batch.retry.support.RetrySynchronizationManager;
import org.springframework.batch.retry.support.RetryTemplate;
-import org.springframework.batch.support.Classifier;
/**
* A special purpose retry template that deals specifically with multi-valued
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessor.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessor.java
index f0c7bb1ee..8e19aa197 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessor.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessor.java
@@ -20,6 +20,8 @@ import java.util.Collections;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.core.StepContribution;
import org.springframework.batch.core.step.skip.LimitCheckingItemSkipPolicy;
import org.springframework.batch.core.step.skip.NonSkippableProcessException;
@@ -31,8 +33,6 @@ import org.springframework.batch.retry.RetryCallback;
import org.springframework.batch.retry.RetryContext;
import org.springframework.batch.retry.RetryException;
import org.springframework.batch.retry.support.DefaultRetryState;
-import org.springframework.batch.support.BinaryExceptionClassifier;
-import org.springframework.batch.support.Classifier;
public class FaultTolerantChunkProcessor extends SimpleChunkProcessor {
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantStepFactoryBean.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantStepFactoryBean.java
index 19e9b905d..3ac9cc4d1 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantStepFactoryBean.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/FaultTolerantStepFactoryBean.java
@@ -21,6 +21,7 @@ import java.util.Collection;
import java.util.HashSet;
import java.util.List;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.core.JobInterruptedException;
import org.springframework.batch.core.step.skip.LimitCheckingItemSkipPolicy;
import org.springframework.batch.core.step.skip.NonSkippableReadException;
@@ -39,7 +40,6 @@ import org.springframework.batch.retry.policy.MapRetryContextCache;
import org.springframework.batch.retry.policy.NeverRetryPolicy;
import org.springframework.batch.retry.policy.RetryContextCache;
import org.springframework.batch.retry.policy.SimpleRetryPolicy;
-import org.springframework.batch.support.Classifier;
/**
* Factory bean for step that provides options for configuring skip behaviour.
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/SimpleRetryExceptionHandler.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/SimpleRetryExceptionHandler.java
index 7b1649bd9..b0d25e011 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/SimpleRetryExceptionHandler.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/item/SimpleRetryExceptionHandler.java
@@ -19,6 +19,7 @@ import java.util.Collection;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.logging.Log;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.exception.ExceptionHandler;
import org.springframework.batch.repeat.support.RepeatSynchronizationManager;
@@ -26,7 +27,6 @@ import org.springframework.batch.retry.RetryCallback;
import org.springframework.batch.retry.RetryContext;
import org.springframework.batch.retry.RetryPolicy;
import org.springframework.batch.retry.listener.RetryListenerSupport;
-import org.springframework.batch.support.BinaryExceptionClassifier;
/**
* An {@link ExceptionHandler} that is aware of the retry context so that it can
diff --git a/spring-batch-core/src/main/java/org/springframework/batch/core/step/skip/LimitCheckingItemSkipPolicy.java b/spring-batch-core/src/main/java/org/springframework/batch/core/step/skip/LimitCheckingItemSkipPolicy.java
index 17acafb66..7048cffe3 100644
--- a/spring-batch-core/src/main/java/org/springframework/batch/core/step/skip/LimitCheckingItemSkipPolicy.java
+++ b/spring-batch-core/src/main/java/org/springframework/batch/core/step/skip/LimitCheckingItemSkipPolicy.java
@@ -18,11 +18,12 @@ package org.springframework.batch.core.step.skip;
import java.io.FileNotFoundException;
import java.util.Collection;
import java.util.Collections;
+
+import org.springframework.batch.classify.BinaryExceptionClassifier;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.StepExecution;
import org.springframework.batch.item.file.FlatFileParseException;
-import org.springframework.batch.support.BinaryExceptionClassifier;
-import org.springframework.batch.support.Classifier;
/**
*
diff --git a/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessorTests.java b/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessorTests.java
index efd08a69b..ce4751282 100644
--- a/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessorTests.java
+++ b/spring-batch-core/src/test/java/org/springframework/batch/core/step/item/FaultTolerantChunkProcessorTests.java
@@ -10,6 +10,7 @@ import java.util.List;
import org.junit.Before;
import org.junit.Test;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
import org.springframework.batch.core.JobExecution;
import org.springframework.batch.core.StepContribution;
import org.springframework.batch.core.StepExecution;
@@ -19,7 +20,6 @@ import org.springframework.batch.item.ItemProcessor;
import org.springframework.batch.item.ItemWriter;
import org.springframework.batch.item.support.PassThroughItemProcessor;
import org.springframework.batch.retry.policy.NeverRetryPolicy;
-import org.springframework.batch.support.BinaryExceptionClassifier;
import org.springframework.dao.DataIntegrityViolationException;
public class FaultTolerantChunkProcessorTests {
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BackToBackPatternClassifier.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BackToBackPatternClassifier.java
similarity index 95%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BackToBackPatternClassifier.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BackToBackPatternClassifier.java
index 5d9793b8d..a2cb385f5 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BackToBackPatternClassifier.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BackToBackPatternClassifier.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import java.util.Map;
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BinaryExceptionClassifier.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BinaryExceptionClassifier.java
similarity index 98%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BinaryExceptionClassifier.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BinaryExceptionClassifier.java
index a035c24cb..3701f5628 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/BinaryExceptionClassifier.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/BinaryExceptionClassifier.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import java.util.Collection;
import java.util.HashMap;
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/Classifier.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/Classifier.java
similarity index 96%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/Classifier.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/Classifier.java
index 8e9719bea..3b937b3c9 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/Classifier.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/Classifier.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
/**
* Interface for a classifier. At its simplest a {@link Classifier} is just a
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierAdapter.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierAdapter.java
similarity index 91%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierAdapter.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierAdapter.java
index 796a8452f..6077e30a8 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierAdapter.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierAdapter.java
@@ -13,8 +13,10 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
+import org.springframework.batch.support.MethodInvoker;
+import org.springframework.batch.support.MethodInvokerUtils;
import org.springframework.util.Assert;
/**
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierSupport.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierSupport.java
similarity index 91%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierSupport.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierSupport.java
index cfce64af8..ad2926378 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/ClassifierSupport.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/ClassifierSupport.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
/**
* Base class for {@link Classifier} implementations. Provides default behaviour
@@ -39,7 +39,7 @@ public class ClassifierSupport implements Classifier {
* Always returns the default value. This is the main extension point for
* subclasses, so it must be able to classify null.
*
- * @see org.springframework.batch.support.Classifier#classify(Object)
+ * @see org.springframework.batch.classify.Classifier#classify(Object)
*/
public T classify(C throwable) {
return defaultValue;
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/PatternMatchingClassifier.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/PatternMatchingClassifier.java
similarity index 92%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/PatternMatchingClassifier.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/PatternMatchingClassifier.java
index c019236bd..11d483517 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/PatternMatchingClassifier.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/PatternMatchingClassifier.java
@@ -13,11 +13,13 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import java.util.HashMap;
import java.util.Map;
+import org.springframework.batch.support.PatternMatcher;
+
/**
* A {@link Classifier} that maps from String patterns with wildcards to a set
* of values of a given type. An input String is matched with the most specific
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/SubclassClassifier.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/SubclassClassifier.java
similarity index 98%
rename from spring-batch-infrastructure/src/main/java/org/springframework/batch/support/SubclassClassifier.java
rename to spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/SubclassClassifier.java
index c35446c75..153498c11 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/support/SubclassClassifier.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/classify/SubclassClassifier.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import java.io.Serializable;
import java.util.Comparator;
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/ClassifierCompositeItemWriter.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/ClassifierCompositeItemWriter.java
index 968b9d1b5..745b94731 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/ClassifierCompositeItemWriter.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/item/support/ClassifierCompositeItemWriter.java
@@ -21,9 +21,9 @@ import java.util.HashMap;
import java.util.List;
import java.util.Map;
+import org.springframework.batch.classify.Classifier;
+import org.springframework.batch.classify.ClassifierSupport;
import org.springframework.batch.item.ItemWriter;
-import org.springframework.batch.support.Classifier;
-import org.springframework.batch.support.ClassifierSupport;
/**
* Calls one of a collection of ItemWriters for each item, based on a router
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandler.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandler.java
index d65aaabff..0ede464a4 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandler.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandler.java
@@ -18,10 +18,10 @@ package org.springframework.batch.repeat.exception;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
+import org.springframework.batch.classify.Classifier;
+import org.springframework.batch.classify.ClassifierSupport;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.RepeatException;
-import org.springframework.batch.support.Classifier;
-import org.springframework.batch.support.ClassifierSupport;
/**
* Implementation of {@link ExceptionHandler} based on an {@link Classifier}.
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/RethrowOnThresholdExceptionHandler.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/RethrowOnThresholdExceptionHandler.java
index 06c39aa32..521daefdd 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/RethrowOnThresholdExceptionHandler.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/repeat/exception/RethrowOnThresholdExceptionHandler.java
@@ -22,10 +22,10 @@ import java.util.Map.Entry;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
+import org.springframework.batch.classify.Classifier;
+import org.springframework.batch.classify.SubclassClassifier;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.context.RepeatContextCounter;
-import org.springframework.batch.support.Classifier;
-import org.springframework.batch.support.SubclassClassifier;
import org.springframework.util.ObjectUtils;
/**
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicy.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicy.java
index d54c15aae..dafe3570b 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicy.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicy.java
@@ -19,12 +19,12 @@ package org.springframework.batch.retry.policy;
import java.util.HashMap;
import java.util.Map;
+import org.springframework.batch.classify.Classifier;
+import org.springframework.batch.classify.ClassifierSupport;
+import org.springframework.batch.classify.SubclassClassifier;
import org.springframework.batch.retry.RetryContext;
import org.springframework.batch.retry.RetryPolicy;
import org.springframework.batch.retry.context.RetryContextSupport;
-import org.springframework.batch.support.Classifier;
-import org.springframework.batch.support.ClassifierSupport;
-import org.springframework.batch.support.SubclassClassifier;
import org.springframework.util.Assert;
/**
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/SimpleRetryPolicy.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/SimpleRetryPolicy.java
index fff8d0c0c..7f4c4328a 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/SimpleRetryPolicy.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/policy/SimpleRetryPolicy.java
@@ -19,10 +19,10 @@ package org.springframework.batch.retry.policy;
import java.util.Collection;
import java.util.HashSet;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
import org.springframework.batch.retry.RetryContext;
import org.springframework.batch.retry.RetryPolicy;
import org.springframework.batch.retry.context.RetryContextSupport;
-import org.springframework.batch.support.BinaryExceptionClassifier;
/**
*
diff --git a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/support/DefaultRetryState.java b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/support/DefaultRetryState.java
index 841ea08a1..212457b25 100644
--- a/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/support/DefaultRetryState.java
+++ b/spring-batch-infrastructure/src/main/java/org/springframework/batch/retry/support/DefaultRetryState.java
@@ -15,11 +15,11 @@
*/
package org.springframework.batch.retry.support;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.retry.RecoveryCallback;
import org.springframework.batch.retry.RetryCallback;
import org.springframework.batch.retry.RetryOperations;
import org.springframework.batch.retry.RetryState;
-import org.springframework.batch.support.Classifier;
/**
*
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BackToBackPatternClassifierTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BackToBackPatternClassifierTests.java
similarity index 88%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BackToBackPatternClassifierTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BackToBackPatternClassifierTests.java
index 03c84f3ff..04b56a622 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BackToBackPatternClassifierTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BackToBackPatternClassifierTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import static org.junit.Assert.assertEquals;
@@ -23,6 +23,8 @@ import java.util.Map;
import org.junit.Before;
import org.junit.Test;
+import org.springframework.batch.classify.BackToBackPatternClassifier;
+import org.springframework.batch.classify.PatternMatchingClassifier;
import org.springframework.batch.support.annotation.Classifier;
/**
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BinaryExceptionClassifierTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BinaryExceptionClassifierTests.java
similarity index 94%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BinaryExceptionClassifierTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BinaryExceptionClassifierTests.java
index d48022ec3..d532b0b4e 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/BinaryExceptionClassifierTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/BinaryExceptionClassifierTests.java
@@ -14,9 +14,12 @@
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import java.util.Collections;
+
+import org.springframework.batch.classify.BinaryExceptionClassifier;
+
import junit.framework.TestCase;
public class BinaryExceptionClassifierTests extends TestCase {
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierAdapterTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierAdapterTests.java
similarity index 89%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierAdapterTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierAdapterTests.java
index 7579da47b..06725dcaf 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierAdapterTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierAdapterTests.java
@@ -13,11 +13,12 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import static org.junit.Assert.assertEquals;
import org.junit.Test;
+import org.springframework.batch.classify.ClassifierAdapter;
import org.springframework.batch.support.annotation.Classifier;
/**
@@ -82,7 +83,7 @@ public class ClassifierAdapterTests {
@Test
public void testClassifierAdapterClassifier() {
adapter = new ClassifierAdapter(
- new org.springframework.batch.support.Classifier() {
+ new org.springframework.batch.classify.Classifier() {
public Integer classify(String classifiable) {
return Integer.valueOf(classifiable);
}
@@ -116,7 +117,7 @@ public class ClassifierAdapterTests {
@Test
public void testClassifyWithClassifier() {
- adapter.setDelegate(new org.springframework.batch.support.Classifier() {
+ adapter.setDelegate(new org.springframework.batch.classify.Classifier() {
public Integer classify(String classifiable) {
return Integer.valueOf(classifiable);
}
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierSupportTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierSupportTests.java
similarity index 91%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierSupportTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierSupportTests.java
index 8a03e95c2..c7fd1b3b8 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/ClassifierSupportTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/ClassifierSupportTests.java
@@ -14,7 +14,9 @@
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
+
+import org.springframework.batch.classify.ClassifierSupport;
import junit.framework.TestCase;
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/PatternMatchingClassifierTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/PatternMatchingClassifierTests.java
similarity index 89%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/PatternMatchingClassifierTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/PatternMatchingClassifierTests.java
index 98b1d616d..6c475b982 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/PatternMatchingClassifierTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/PatternMatchingClassifierTests.java
@@ -13,7 +13,7 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import static org.junit.Assert.*;
@@ -22,6 +22,7 @@ import java.util.Map;
import org.junit.Before;
import org.junit.Test;
+import org.springframework.batch.classify.PatternMatchingClassifier;
/**
* @author Dave Syer
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/SubclassExceptionClassifierTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/SubclassExceptionClassifierTests.java
similarity index 96%
rename from spring-batch-infrastructure/src/test/java/org/springframework/batch/support/SubclassExceptionClassifierTests.java
rename to spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/SubclassExceptionClassifierTests.java
index 495d2db39..696b6caa8 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/support/SubclassExceptionClassifierTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/classify/SubclassExceptionClassifierTests.java
@@ -14,7 +14,7 @@
* limitations under the License.
*/
-package org.springframework.batch.support;
+package org.springframework.batch.classify;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;
@@ -23,6 +23,7 @@ import java.util.Collections;
import java.util.HashMap;
import org.junit.Test;
+import org.springframework.batch.classify.SubclassClassifier;
public class SubclassExceptionClassifierTests {
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/item/support/ClassifierCompositeItemWriterTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/item/support/ClassifierCompositeItemWriterTests.java
index f8542cc38..22b21345b 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/item/support/ClassifierCompositeItemWriterTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/item/support/ClassifierCompositeItemWriterTests.java
@@ -24,8 +24,8 @@ import java.util.List;
import java.util.Map;
import org.junit.Test;
+import org.springframework.batch.classify.PatternMatchingClassifier;
import org.springframework.batch.item.ItemWriter;
-import org.springframework.batch.support.PatternMatchingClassifier;
/**
* @author Dave Syer
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandlerTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandlerTests.java
index 77fc53154..d6174b339 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandlerTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/repeat/exception/LogOrRethrowExceptionHandlerTests.java
@@ -23,9 +23,9 @@ import junit.framework.TestCase;
import org.apache.log4j.Logger;
import org.apache.log4j.SimpleLayout;
import org.apache.log4j.WriterAppender;
+import org.springframework.batch.classify.ClassifierSupport;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.exception.LogOrRethrowExceptionHandler.Level;
-import org.springframework.batch.support.ClassifierSupport;
public class LogOrRethrowExceptionHandlerTests extends TestCase {
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicyTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicyTests.java
index 795118021..d0edb6d90 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicyTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/policy/ExceptionClassifierRetryPolicyTests.java
@@ -20,9 +20,9 @@ import java.util.Collections;
import java.util.HashMap;
import junit.framework.TestCase;
+import org.springframework.batch.classify.Classifier;
import org.springframework.batch.retry.RetryContext;
import org.springframework.batch.retry.RetryPolicy;
-import org.springframework.batch.support.Classifier;
public class ExceptionClassifierRetryPolicyTests extends TestCase {
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/RetryTemplateTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/RetryTemplateTests.java
index 9d35d77fb..2a44861f4 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/RetryTemplateTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/RetryTemplateTests.java
@@ -27,6 +27,7 @@ import static org.easymock.EasyMock.*;
import java.util.Collections;
import org.junit.Test;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
import org.springframework.batch.retry.ExhaustedRetryException;
import org.springframework.batch.retry.RecoveryCallback;
import org.springframework.batch.retry.RetryCallback;
@@ -37,7 +38,6 @@ import org.springframework.batch.retry.backoff.BackOffPolicy;
import org.springframework.batch.retry.backoff.StatelessBackOffPolicy;
import org.springframework.batch.retry.policy.NeverRetryPolicy;
import org.springframework.batch.retry.policy.SimpleRetryPolicy;
-import org.springframework.batch.support.BinaryExceptionClassifier;
/**
* @author Rob Harrop
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/StatefulRecoveryRetryTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/StatefulRecoveryRetryTests.java
index 376c5ecc4..9f37dac1e 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/StatefulRecoveryRetryTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/StatefulRecoveryRetryTests.java
@@ -27,6 +27,7 @@ import java.util.Collections;
import java.util.List;
import org.junit.Test;
+import org.springframework.batch.classify.BinaryExceptionClassifier;
import org.springframework.batch.repeat.RepeatContext;
import org.springframework.batch.repeat.context.RepeatContextSupport;
import org.springframework.batch.repeat.support.RepeatSynchronizationManager;
@@ -40,7 +41,6 @@ import org.springframework.batch.retry.RetryPolicy;
import org.springframework.batch.retry.policy.MapRetryContextCache;
import org.springframework.batch.retry.policy.NeverRetryPolicy;
import org.springframework.batch.retry.policy.SimpleRetryPolicy;
-import org.springframework.batch.support.BinaryExceptionClassifier;
import org.springframework.dao.DataAccessException;
public class StatefulRecoveryRetryTests {
diff --git a/spring-batch-parent/pom.xml b/spring-batch-parent/pom.xml
index abbcfa20b..74c9945cb 100644
--- a/spring-batch-parent/pom.xml
+++ b/spring-batch-parent/pom.xml
@@ -117,10 +117,6 @@
com.springsource.bundlor.maven
${bundlor.version}
true
-
- ${project.basedir}/template.mf
- ${project.basedir}/src/main/resources/META-INF/MANIFEST.MF
-
bundlor-transform
diff --git a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/DefaultRetryStateTests.java b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/DefaultRetryStateTests.java
index 9d13caaeb..7e745663e 100644
--- a/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/DefaultRetryStateTests.java
+++ b/spring-batch-infrastructure/src/test/java/org/springframework/batch/retry/support/DefaultRetryStateTests.java
@@ -20,7 +20,7 @@ import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import org.junit.Test;
-import org.springframework.batch.support.Classifier;
+import org.springframework.batch.classify.Classifier;
/**
* @author Dave Syer
@@ -30,7 +30,7 @@ public class DefaultRetryStateTests {
/**
* Test method for
* {@link org.springframework.batch.retry.support.DefaultRetryState#DefaultRetryState(java.lang.Object, boolean, org.springframework.batch.support.Classifier)}.
*/
@Test
public void testDefaultRetryStateObjectBooleanClassifierOfQsuperThrowableBoolean() {
@@ -46,7 +46,7 @@ public class DefaultRetryStateTests {
/**
* Test method for
- * {@link org.springframework.batch.retry.support.DefaultRetryState#DefaultRetryState(java.lang.Object, org.springframework.batch.support.Classifier)}.
+ * {@link org.springframework.batch.retry.support.DefaultRetryState#DefaultRetryState(java.lang.Object, org.springframework.batch.classify.Classifier)}.
*/
@Test
public void testDefaultRetryStateObjectClassifierOfQsuperThrowableBoolean() {
@@ -30,7 +30,7 @@ public class DefaultRetryStateTests {
/**
* Test method for
- * {@link org.springframework.batch.retry.support.DefaultRetryState#DefaultRetryState(java.lang.Object, boolean, org.springframework.batch.support.Classifier)}.
+ * {@link org.springframework.batch.retry.support.DefaultRetryState#DefaultRetryState(java.lang.Object, boolean, org.springframework.batch.classify.Classifier)}.
*/